@@ -1,6 +1,7 @@
 """Build and manage distributions
 """
 import logging
+import shutil
 
 from invoke import run
 
@@ -10,11 +11,13 @@ logger = logging.getLogger(__name__)
 
 
 def should_build():
-    upload_pypi = config.get("upload_to_pypi")
+    upload_to_artifact_repository = config.get("upload_to_repository") and config.get(
+        "upload_to_pypi"
+    )
     upload_release = config.get("upload_to_release")
     build_command = config.get("build_command")
     build_command = build_command if build_command != "false" else False
-    return bool(build_command and (upload_pypi or upload_release))
+    return bool(build_command and (upload_to_artifact_repository or upload_release))
 
 
 def should_remove_dist():
@@ -29,6 +32,5 @@ def build_dists():
 
 
 def remove_dists(path: str):
-    command = f"rm -rf {path}"
-    logger.debug(f"Running {command}")
-    run(command)
+    logger.debug(f"Removing build folder: `{path}`")
+    shutil.rmtree(path, ignore_errors=True)
